@@ -4,4 +4,5 @@ utils::globalVariables(c('team', 'more', 'rec', 'seed', 'barthag','auto_prob','b
                          'pake', 'coach','result','score','points','opp_points','opp_conf','loc','lead_diff',
                          'V3', '.', 'ast', 'away', 'blk', 'fta', 'ftm', 'games', 'home', 'key', 'pf', 'pts',
                          'stl', 'team1', 'team2', 'to', 'tpa', 'tpm', 'value', 'where', 'ts', 'num', 'abrev',
-                         'player', 'is_installed'))
+                         'player', 'is_installed', 'player_id', 'current_env', 'check_dots_empty0',
+                         'ffi_list_unchop'))
